package ittp.protocol;

import ittp.Server;
import ittp.ittpException;
import ittp.protocol.response.Response;
import java.text.SimpleDateFormat;
import java.text.DateFormat;
import java.util.Locale;

/**
 * This class determine the version of the protocol ITTP used by the client.
 * This class contains the different tools used by the server.
 * @author Frederic Bidon and Mathieu Texier
 */
public class Protocol {
    final static public double VERSION = 1.3;
    protected String ITTP_version;
    static public DateFormat dateFormat = new SimpleDateFormat ("EE, d MMM yyyy HH:mm:ss z", Locale.ENGLISH);
    /** Creates a new instance of Protocole */
    public Protocol () {
    }
    
    /**
     * Accessor for the string ITTP-version.
     * @return the ITTP version used by the client.
     */
    public String getITTP_version () {
        return ITTP_version;
    }
    
    /**
     * Mutators for the ITTP version of the client.
     * @param ITTP_version String containing the version of the protocol ITTP used by the client.
     * @throws ittpException if the version of the client and the version of the server of the ITTP protocol are not the same
     */
    public void setITTP_version (String ITTP_version) throws ittpException {
        this.ITTP_version = ITTP_version;
        if (ITTP_version.compareTo ("ITTP/" + Double.toString (VERSION)) != 0)
            throw new ittpException ("Invalid ITTP version", Response.Code.ITTP_VERSION);
    }
}
